#
# spec file for package libwrc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libwrc
%define lname	libwrc1
Version:        20240421
Release:        1.1
Summary:        Library to support the Windows Resource Compiler format
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libwrc
Source:         https://github.com/libyal/%name/releases/download/%version/%name-experimental-%version.tar.gz
Source2:        https://github.com/libyal/%name/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source9:        %name.keyring
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libexe) >= 20210424
BuildRequires:  pkgconfig(libfcache) >= 20240414
BuildRequires:  pkgconfig(libfdata) >= 20240415
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libfvalue) >= 20240415
BuildRequires:  pkgconfig(libfwnt) >= 20240415
BuildRequires:  pkgconfig(libuna) >= 20240414
BuildRequires:  pkgconfig(python3)
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libwrc is a library to support the Windows Resource Compiler format.

%package -n %lname
Summary:        Library to support the Windows Resource Compiler format
Group:          System/Libraries

%description -n %lname
libwrc is a library to support the Windows Resource Compiler format.

%package devel
Summary:        Development files for libwrc, a Windows Resouce Compiler format support library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libwrc is a library to support the Windows Resource Compiler format.

This subpackage contains libraries and header files for developing
applications that want to make use of libwrc.

%package tools
Summary:        Utilities to inspect Windows Resource Compiler files
Group:          Productivity/File utilities

%description tools
This subpackage provides the utilities from libwrc, which allows for
reading Windows Resource Compiler files.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* "%buildroot/"
find "%buildroot" -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libwrc.so.1*

%files -n %name-devel
%_includedir/libwrc*
%_libdir/libwrc.so
%_libdir/pkgconfig/libwrc.pc
%_mandir/man3/libwrc.3*

%files -n %name-tools
%_bindir/wrcinfo
%_mandir/man1/wrcinfo.1*

%files %python_files
%python_sitearch/*.so

%changelog
* Sun Apr 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240421
  * No changelog was provided
* Sat Feb 17 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240117
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Thu Dec 28 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231228
  * Unspecified updates to Python bindings
* Sat Dec  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231202
  * Improved Python Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Mon Mar 20 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230318
  * No changelog provided
* Wed Feb 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to reelease 20230214
  * No changelog provided
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Fri Nov  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221009
  * Format support improvements
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sun Jul 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220720
  * Removed WEVT_TEMPLATE resource support
  * Drop use of libfwevt
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Edit specfile to do multipython builds.
* Tue Jan  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220104
  * Unspecific updates to Python bindings
* Mon Jan  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220103
  * New libwrc_mui_resource functions
* Fri Dec 31 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211231
  * Unspecified updates to the library and Python bindings.
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210425 (89146ffc)
  * No changelog was provided
- Add system-libs.patch
- Enable python3 integration
* Wed Dec 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
-  update to v0~20191221
  * changes for libuna
-  remove BuildRequires:  pkg-config
-  add COPYING* to %%license line
* Thu Mar 28 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
-  update to v0~20181203
  * changes for libuna API changes
  * Updated synclibs.ps1 to use latest tagged version
  * combined on Python 2 and 3 support
* Wed Feb  3 2016 Greg.Freemyer@gmail.com
-  update to v0~20160111
  * worked on Python 3 support
  * 2016 update
  * code clean up
* Mon Jan 12 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * added Windows codepage 932, 936 and 1255 support
  * code clean up
  * bug fix in Python-bindings
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using new libyal packages from OBS, not internal version
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- updated to v0~20140803
  * bug fix in Python-bindings
  * updated dependencies
  * Worked on Python bindings
  * worked on format support
  * worked on stripping trailing 0-byte values from message table strings
  * improved handling of version resource
  * Worked on Python bindings
  - clean up and bug fixes
  - added MUI type support
  * small fixes for file IO handle opened in library changes
  * 2014 update
* Wed Oct 23 2013 Greg.Freemyer@gmail.com
- updated to v0~20131017
  * updated dependencies
  * worked on libcthreads build support
  * Worked on version resource support
  * added pywrc
  * 2013 update
  * changes for libfdata update
- converted to gz compression to eliminate conversion during update
- verified BuildRequires and used version from factory when possible
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- re-organize BuildRequires and comment why commented out
- uncomment BuildRequires (libcnotify) since the version in factory seems to work fine
- ran spec-cleaner
* Wed Apr  3 2013 jengelh@inai.de
- Initial package (version 0~20121225) for build.opensuse.org
